@@ -151,7 +151,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                                     Ok(message) => {
                                         println!("Received: {:?}", message);
                                         match context_provider.new_context().await {
-                                            Ok(ctx) => {
+                                            Ok(mut ctx) => {
                                                 let processing_result = process_handler(&internal_ctx, &mut ctx, message.0).await;
                                                 if processing_result.is_ok() {
                                                     subscription.acknowledge_messages(vec![ack_id]).await;
